==> global-0.0.5.tar.gz: lib/src/GHttpReqs.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:global/global.dart';
import 'package:http/http.dart' as http;
import 'package:http/http.dart';

class GHttpReqs {
  //Utility function for making http requests
  static Future<Response> send({
    GlobalKey<NavigatorState>? navigatorKey,
    bool isPostRequest = true,
    required String url,
    String authorization = '',
    String contentType = GValues.applnSlashJson,
    Object? body,
    Function(Response)? onResponse,
    Function? onError,
  }) {
    if (navigatorKey != null) {
      GUtils.showProgressDialog(navigatorKey: navigatorKey);
    }
    Future<Response> responseFuture = isPostRequest
        ? http.post(Uri.parse(url),
            body: body,
            headers: GUtils.getBasicHeaders(
                authorization: authorization, contentType: contentType))
        : http.get(Uri.parse(url));
    _attachHandlerToBaseResponseFuture(
        baseRespFuture: responseFuture,
        navigatorKey: navigatorKey,
        onResponse: onResponse,
        onError: onError);
    return responseFuture;
  }

  static _attachHandlerToBaseResponseFuture({
    required Future<BaseResponse> baseRespFuture,
    GlobalKey<NavigatorState>? navigatorKey,
    Function(Response)? onResponse,
    Function? onError,
  }) =>
      baseRespFuture.then(
        (baseResp) async {
          if (navigatorKey != null) navigatorKey.currentState!.pop();
          if (onResponse != null) {
            onResponse(baseResp is StreamedResponse
                ? await Response.fromStream(baseResp)
                : baseResp as Response);
          }
        },
        onError: (error) {
          if (error is SocketException && error.osError?.errorCode == 51) {
            GUtils.showToast(
                message: GTexts.plzChkNetwork,
                toastWithDuration: Toast.LENGTH_LONG);
          }
          if (navigatorKey != null) navigatorKey.currentState!.pop();
          if (onError != null) onError();
        },
      );

  //Utility function for firing Multi-part request
  static Future<StreamedResponse> sendMultipart(
      {GlobalKey<NavigatorState>? navigatorKey,
      required MultipartRequest request,
      Function(Response)? onResponse,
      Function? onError}) {
    if (navigatorKey != null) {
      GUtils.showProgressDialog(navigatorKey: navigatorKey);
    }
    var streamedRespFuture = request.send();
    _attachHandlerToBaseResponseFuture(
        baseRespFuture: streamedRespFuture,
        navigatorKey: navigatorKey,
        onResponse: onResponse,
        onError: onError);
    return streamedRespFuture;
  }
}

==> global-0.0.8.tar.gz: lib/src/GHttpReqs.dart <==
import 'dart:io';

import 'package:global/global.dart';
import 'package:http/http.dart' as http;

class GHttpReqs {
  //Utility function for making http requests
  static Future<Response> send({
    bool showDialog = true,
    bool isPostRequest = true,
    required String url,
    String authorization = '',
    String contentType = GValues.applnSlashJson,
    Object? body,
    Function(Response)? onResponse,
    Function? onError,
  }) {
    if (showDialog) {
      GUtils.showProgressDialog();
    }
    Future<Response> responseFuture = isPostRequest
        ? http.post(Uri.parse(url),
            body: body,
            headers: GUtils.getBasicHeaders(
                authorization: authorization, contentType: contentType))
        : http.get(Uri.parse(url));
    _attachHandlerToBaseResponseFuture(
        baseRespFuture: responseFuture,
        showDialog: showDialog,
        onResponse: onResponse,
        onError: onError);
    return responseFuture;
  }

  static _attachHandlerToBaseResponseFuture({
    required Future<BaseResponse> baseRespFuture,
    bool showDialog = true,
    Function(Response)? onResponse,
    Function? onError,
  }) =>
      baseRespFuture.then(
        (baseResp) async {
          if (showDialog) Global.navigatorKey.currentState!.pop();
          if (onResponse != null) {
            onResponse(baseResp is StreamedResponse
                ? await Response.fromStream(baseResp)
                : baseResp as Response);
          }
        },
        onError: (error) {
          if (error is SocketException && error.osError?.errorCode == 51) {
            GUtils.showToast(
                message: GTexts.plzChkNetwork,
                toastWithDuration: Toast.LENGTH_LONG);
          }
          if (showDialog) Global.navigatorKey.currentState!.pop();
          if (onError != null) onError();
        },
      );

  //Utility function for firing Multi-part request
  static Future<StreamedResponse> sendMultipart(
      {bool showDialog = true,
      required MultipartRequest request,
      Function(Response)? onResponse,
      Function? onError}) {
    if (showDialog) {
      GUtils.showProgressDialog();
    }
    var streamedRespFuture = request.send();
    _attachHandlerToBaseResponseFuture(
        baseRespFuture: streamedRespFuture,
        showDialog: showDialog,
        onResponse: onResponse,
        onError: onError);
    return streamedRespFuture;
  }
}
